==> pegasus-support-2.2.9-sources.jar: com/thebeastshop/support/vo/lesson/MyCourse.java <==
package com.thebeastshop.support.vo.lesson;


import com.thebeastshop.support.enums.lesson.CourseTimeStatus;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * Created by GFL on 2019/3/4.
 */
public class MyCourse implements Serializable {
    private static final long serialVersionUID = 6946973789277326281L;

    private String code;
    private String name;
    private String cityName;
    private String address;
    private String courseTime;
    private CourseTimeStatus status;
    private String tips;
    private List<MyCourseCode> courseCodes;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getCourseTime() {
        return courseTime;
    }

    public void setCourseTime(String courseTime) {
        this.courseTime = courseTime;
    }

    public CourseTimeStatus getStatus() {
        return status;
    }

    public void setStatus(CourseTimeStatus status) {
        this.status = status;
    }

    public String getTips() {
        return tips;
    }

    public void setTips(String tips) {
        this.tips = tips;
    }

    public List<MyCourseCode> getCourseCodes() {
        return courseCodes;
    }

    public void setCourseCodes(List<MyCourseCode> courseCodes) {
        this.courseCodes = courseCodes;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("code", code)
                .append("name", name)
                .append("cityName", cityName)
                .append("address", address)
                .append("courseTime", courseTime)
                .append("status", status)
                .append("tips", tips)
                .append("courseCodes", courseCodes)
                .toString();
    }
}

==> pegasus-support-2.5.5-sources.jar: com/thebeastshop/support/vo/lesson/MyCourse.java <==
package com.thebeastshop.support.vo.lesson;


import com.thebeastshop.support.enums.lesson.CourseTimeStatus;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * Created by GFL on 2019/3/4.
 */
public class MyCourse implements Serializable {
    private static final long serialVersionUID = 6946973789277326281L;

    private String code;
    private String productCode;
    private String prodId;
    private String orderCode;
    private String name;
    private String cityName;
    private String address;
    private String courseTime;
    private CourseTimeStatus status;
    private String tips;
    private List<MyCourseCode> courseCodes;
    /**
     * 扩展信息，存储json格式数据
     * 鲜花市场券通过课堂发放，追加的附属信息
     */
    private Object extend;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProdId() {
        return prodId;
    }

    public void setProdId(String prodId) {
        this.prodId = prodId;
    }

    public String getOrderCode() {
        return orderCode;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getCourseTime() {
        return courseTime;
    }

    public void setCourseTime(String courseTime) {
        this.courseTime = courseTime;
    }

    public CourseTimeStatus getStatus() {
        return status;
    }

    public void setStatus(CourseTimeStatus status) {
        this.status = status;
    }

    public String getTips() {
        return tips;
    }

    public void setTips(String tips) {
        this.tips = tips;
    }

    public List<MyCourseCode> getCourseCodes() {
        return courseCodes;
    }

    public void setCourseCodes(List<MyCourseCode> courseCodes) {
        this.courseCodes = courseCodes;
    }

    public Object getExtend() {
        return extend;
    }

    public void setExtend(Object extend) {
        this.extend = extend;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("code", code)
                .append("productCode", productCode)
                .append("prodId", prodId)
                .append("orderCode", orderCode)
                .append("name", name)
                .append("cityName", cityName)
                .append("address", address)
                .append("courseTime", courseTime)
                .append("status", status)
                .append("tips", tips)
                .append("courseCodes", courseCodes)
                .append("extend", extend)
                .toString();
    }
}
